summaryrefslogtreecommitdiffhomepage
path: root/examples/textures/textures_npatch_drawing.c
diff options
context:
space:
mode:
authorRay <[email protected]>2021-03-03 19:36:28 +0100
committerRay <[email protected]>2021-03-03 19:36:28 +0100
commit408f5aedb8d4966aec3eea47524b7460be9446ea (patch)
tree194276900a97ba4b50d0f80ab2319754ec194cd2 /examples/textures/textures_npatch_drawing.c
parent81908f7960005e35a50d0675e970483989cd7ff2 (diff)
downloadraylib-408f5aedb8d4966aec3eea47524b7460be9446ea.tar.gz
raylib-408f5aedb8d4966aec3eea47524b7460be9446ea.zip
WARNING: BREAKING: RENAMED enum values
RENAMED: CubemapLayoutType and NPatchType
Diffstat (limited to 'examples/textures/textures_npatch_drawing.c')
-rw-r--r--examples/textures/textures_npatch_drawing.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/examples/textures/textures_npatch_drawing.c b/examples/textures/textures_npatch_drawing.c
index 1c57e2e7..170b992f 100644
--- a/examples/textures/textures_npatch_drawing.c
+++ b/examples/textures/textures_npatch_drawing.c
@@ -36,15 +36,15 @@ int main(void)
Rectangle dstRecH = { 160.0f, 93.0f, 32.0f, 32.0f };
Rectangle dstRecV = { 92.0f, 160.0f, 32.0f, 32.0f };
- // A 9-patch (NPT_9PATCH) changes its sizes in both axis
- NPatchInfo ninePatchInfo1 = { (Rectangle){ 0.0f, 0.0f, 64.0f, 64.0f }, 12, 40, 12, 12, NPT_9PATCH };
- NPatchInfo ninePatchInfo2 = { (Rectangle){ 0.0f, 128.0f, 64.0f, 64.0f }, 16, 16, 16, 16, NPT_9PATCH };
+ // A 9-patch (NPATCH_NINE_PATCH) changes its sizes in both axis
+ NPatchInfo ninePatchInfo1 = { (Rectangle){ 0.0f, 0.0f, 64.0f, 64.0f }, 12, 40, 12, 12, NPATCH_NINE_PATCH };
+ NPatchInfo ninePatchInfo2 = { (Rectangle){ 0.0f, 128.0f, 64.0f, 64.0f }, 16, 16, 16, 16, NPATCH_NINE_PATCH };
- // A horizontal 3-patch (NPT_3PATCH_HORIZONTAL) changes its sizes along the x axis only
- NPatchInfo h3PatchInfo = { (Rectangle){ 0.0f, 64.0f, 64.0f, 64.0f }, 8, 8, 8, 8, NPT_3PATCH_HORIZONTAL };
+ // A horizontal 3-patch (NPATCH_THREE_PATCH_HORIZONTAL) changes its sizes along the x axis only
+ NPatchInfo h3PatchInfo = { (Rectangle){ 0.0f, 64.0f, 64.0f, 64.0f }, 8, 8, 8, 8, NPATCH_THREE_PATCH_HORIZONTAL };
- // A vertical 3-patch (NPT_3PATCH_VERTICAL) changes its sizes along the y axis only
- NPatchInfo v3PatchInfo = { (Rectangle){ 0.0f, 192.0f, 64.0f, 64.0f }, 6, 6, 6, 6, NPT_3PATCH_VERTICAL };
+ // A vertical 3-patch (NPATCH_THREE_PATCH_VERTICAL) changes its sizes along the y axis only
+ NPatchInfo v3PatchInfo = { (Rectangle){ 0.0f, 192.0f, 64.0f, 64.0f }, 6, 6, 6, 6, NPATCH_THREE_PATCH_VERTICAL };
SetTargetFPS(60);
//---------------------------------------------------------------------------------------